@@ -1576,7 +1576,7 @@ class ScopeDisplay(wx.Frame):
         self.toolBox.Add(self.activeTog, 0, wx.TOP|wx.LEFT|wx.RIGHT, 5)
         self.toolBox.AddSpacer(10)
         self.toolBox.Add(wx.StaticText(self.panel, -1, label="Window length (ms):"), 0, wx.TOP, 11)
-        self.lenSlider = ControlSlider(self.panel, 10, 60, length * 1000, outFunction=self.setLength)
+        self.lenSlider = ControlSlider(self.panel, 10, 1000, length * 1000, log=True, outFunction=self.setLength)
         self.toolBox.Add(self.lenSlider, 1, wx.TOP|wx.LEFT|wx.RIGHT, 11)
         self.toolBox.AddSpacer(40)
         self.mainBox.Add(self.toolBox, 0, wx.EXPAND)
@@ -1584,9 +1584,9 @@ class ScopeDisplay(wx.Frame):
         self.box = wx.BoxSizer(wx.VERTICAL)
         self.scopePanel = ScopePanel(self.panel, self.obj)
         self.box.Add(self.scopePanel, 1, wx.EXPAND|wx.LEFT|wx.RIGHT, 5)
-        self.dispBox.Add(self.box, 1, wx.EXPAND, 0)
+        self.dispBox.Add(self.box, 1, wx.EXPAND|wx.BOTTOM, 5)
         self.gainSlider = ControlSlider(self.panel, -24, 24, 20.0 * math.log10(gain), outFunction=self.setGain, orient=wx.VERTICAL)
-        self.dispBox.Add(self.gainSlider, 0, wx.EXPAND)
+        self.dispBox.Add(self.gainSlider, 0, wx.EXPAND|wx.BOTTOM, 5)
         self.dispBox.AddSpacer(5)
         self.mainBox.Add(self.dispBox, 1, wx.EXPAND)
         self.panel.SetSizer(self.mainBox)
@@ -1641,7 +1641,6 @@ class ScopePanel(wx.Panel):
 
     def setGain(self, gain):
         self.gain = gain
-        print self.gain
 
     def setLength(self, length):
         self.length = length
