@@ -60,6 +60,7 @@ class Follower(PyoObject):
 
     """
     def __init__(self, input, freq=20, mul=1, add=0):
+        pyoArgsAssert(self, "oOOO", input, freq, mul, add)
         PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
@@ -79,6 +80,7 @@ class Follower(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -92,6 +94,7 @@ class Follower(PyoObject):
                 New `freq` attribute.
 
         """
+        pyoArgsAssert(self, "O", x)
         self._freq = x
         x, lmax = convertArgsToLists(x)
         [obj.setFreq(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -147,6 +150,7 @@ class Follower2(PyoObject):
 
     """
     def __init__(self, input, risetime=0.01, falltime=0.1, mul=1, add=0):
+        pyoArgsAssert(self, "oOOOO", input, risetime, falltime, mul, add)
         PyoObject.__init__(self, mul, add)
         self._input = input
         self._risetime = risetime
@@ -167,6 +171,7 @@ class Follower2(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -180,6 +185,7 @@ class Follower2(PyoObject):
                 New `risetime` attribute.
 
         """
+        pyoArgsAssert(self, "O", x)
         self._risetime = x
         x, lmax = convertArgsToLists(x)
         [obj.setRisetime(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -194,6 +200,7 @@ class Follower2(PyoObject):
                 New `falltime` attribute.
 
         """
+        pyoArgsAssert(self, "O", x)
         self._falltime = x
         x, lmax = convertArgsToLists(x)
         [obj.setFalltime(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -256,6 +263,7 @@ class ZCross(PyoObject):
 
     """
     def __init__(self, input, thresh=0., mul=1, add=0):
+        pyoArgsAssert(self, "onOO", input, thresh, mul, add)
         PyoObject.__init__(self, mul, add)
         self._input = input
         self._thresh = thresh
@@ -275,6 +283,7 @@ class ZCross(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -288,6 +297,7 @@ class ZCross(PyoObject):
                 New amplitude difference threshold.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._thresh = x
         x, lmax = convertArgsToLists(x)
         [obj.setThresh(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -363,6 +373,7 @@ class Yin(PyoObject):
 
     """
     def __init__(self, input, tolerance=0.2, minfreq=40, maxfreq=1000, cutoff=1000, winsize=1024, mul=1, add=0):
+        pyoArgsAssert(self, "onnnniOO", input, tolerance, minfreq, maxfreq, cutoff, winsize, mul, add)
         PyoObject.__init__(self, mul, add)
         self._input = input
         self._tolerance = tolerance
@@ -385,6 +396,7 @@ class Yin(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -398,6 +410,7 @@ class Yin(PyoObject):
                 New parameter for minima selection, between 0 and 1.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._tolerance = x
         x, lmax = convertArgsToLists(x)
         [obj.setTolerance(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -412,6 +425,7 @@ class Yin(PyoObject):
                 New minimum frequency detected.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._minfreq = x
         x, lmax = convertArgsToLists(x)
         [obj.setMinfreq(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -426,6 +440,7 @@ class Yin(PyoObject):
                 New maximum frequency detected.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._maxfreq = x
         x, lmax = convertArgsToLists(x)
         [obj.setMaxfreq(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -440,6 +455,7 @@ class Yin(PyoObject):
                 New input lowpass filter cutoff frequency.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._cutoff = x
         x, lmax = convertArgsToLists(x)
         [obj.setCutoff(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -526,6 +542,7 @@ class Centroid(PyoObject):
 
     """
     def __init__(self, input, size=1024, mul=1, add=0):
+        pyoArgsAssert(self, "oiOO", input, size, mul, add)
         PyoObject.__init__(self, mul, add)
         self._input = input
         self._size = size
@@ -545,6 +562,7 @@ class Centroid(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -566,7 +584,7 @@ class AttackDetector(PyoObject):
     """
     Audio signal onset detection.
 
-    AttackDetector anaylises an audio signal in input an output a trigger each
+    AttackDetector analyses an audio signal in input and output a trigger each
     time an onset is detected. An onset is a sharp amplitude rising while the
     signal had previously fall below a minimum threshold. Parameters must be
     carefully tuned depending on the nature of the analysed signal and the level
@@ -605,6 +623,7 @@ class AttackDetector(PyoObject):
 
     """
     def __init__(self, input, deltime=0.005, cutoff=10, maxthresh=3, minthresh=-30, reltime=0.1, mul=1, add=0):
+        pyoArgsAssert(self, "onnnnnOO", input, deltime, cutoff, maxthresh, minthresh, reltime, mul, add)
         PyoObject.__init__(self, mul, add)
         self._input = input
         self._deltime = deltime
@@ -628,6 +647,7 @@ class AttackDetector(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -641,6 +661,7 @@ class AttackDetector(PyoObject):
                 New delay between rms analysis.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._deltime = x
         x, lmax = convertArgsToLists(x)
         [obj.setDeltime(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -655,6 +676,7 @@ class AttackDetector(PyoObject):
                 New cutoff for the follower lowpass filter.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._cutoff = x
         x, lmax = convertArgsToLists(x)
         [obj.setCutoff(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -669,6 +691,7 @@ class AttackDetector(PyoObject):
                 New attack threshold in dB.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._maxthresh = x
         x, lmax = convertArgsToLists(x)
         [obj.setMaxthresh(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -683,6 +706,7 @@ class AttackDetector(PyoObject):
                 New minimum threshold in dB.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._minthresh = x
         x, lmax = convertArgsToLists(x)
         [obj.setMinthresh(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -697,6 +721,7 @@ class AttackDetector(PyoObject):
                 Time, in seconds, to wait before reporting a new attack.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._reltime = x
         x, lmax = convertArgsToLists(x)
         [obj.setReltime(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -803,6 +828,7 @@ class Spectrum(PyoObject):
 
     """
     def __init__(self, input, size=1024, wintype=2, function=None):
+        pyoArgsAssert(self, "oiiC", input, size, wintype, function)
         PyoObject.__init__(self)
         self.points = None
         self.viewFrame = None
@@ -836,6 +862,7 @@ class Spectrum(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -849,6 +876,7 @@ class Spectrum(PyoObject):
                 new `size` attribute.
 
         """
+        pyoArgsAssert(self, "i", x)
         self._size = x
         x, lmax = convertArgsToLists(x)
         [obj.setSize(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -863,6 +891,7 @@ class Spectrum(PyoObject):
                 new `wintype` attribute.
 
         """
+        pyoArgsAssert(self, "i", x)
         self._wintype = x
         x, lmax = convertArgsToLists(x)
         [obj.setWinType(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -879,6 +908,7 @@ class Spectrum(PyoObject):
                 and will receive the data as a list of lists (one list per channel).
 
         """
+        pyoArgsAssert(self, "C", function)
         self._function = getWeakMethodRef(function)
 
     def poll(self, active):
@@ -892,6 +922,7 @@ class Spectrum(PyoObject):
                 defaults to True.
 
         """
+        pyoArgsAssert(self, "B", active)
         if active:
             self._timer.play()
         else:
@@ -908,6 +939,7 @@ class Spectrum(PyoObject):
                 retrieve the current analysis frame. defaults to 0.05.
 
         """
+        pyoArgsAssert(self, "N", time)
         self._timer.time = time
 
     def setLowbound(self, x):
@@ -922,6 +954,7 @@ class Spectrum(PyoObject):
                 new `lowbound` attribute.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._lowbound = x
         x, lmax = convertArgsToLists(x)
         tmp = [obj.setLowbound(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -939,6 +972,7 @@ class Spectrum(PyoObject):
                 new `highbound` attribute.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._highbound = x
         x, lmax = convertArgsToLists(x)
         tmp = [obj.setHighbound(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -971,6 +1005,7 @@ class Spectrum(PyoObject):
                 new `width` attribute.
 
         """
+        pyoArgsAssert(self, "i", x)
         self._width = x
         x, lmax = convertArgsToLists(x)
         [obj.setWidth(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -987,6 +1022,7 @@ class Spectrum(PyoObject):
                 new `height` attribute.
 
         """
+        pyoArgsAssert(self, "i", x)
         self._height = x
         x, lmax = convertArgsToLists(x)
         [obj.setHeight(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -1002,6 +1038,7 @@ class Spectrum(PyoObject):
                 it back to linear. Defaults to False.
 
         """
+        pyoArgsAssert(self, "b", x)
         self._fscaling = x
         x, lmax = convertArgsToLists(x)
         [obj.setFscaling(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -1019,6 +1056,7 @@ class Spectrum(PyoObject):
                 False turns it back to linear. Defaults to True.
 
         """
+        pyoArgsAssert(self, "b", x)
         self._mscaling = x
         x, lmax = convertArgsToLists(x)
         [obj.setMscaling(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -1053,6 +1091,7 @@ class Spectrum(PyoObject):
                 new `gain` attribute, as linear values.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._gain = x
         x, lmax = convertArgsToLists(x)
         [obj.setGain(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -1073,6 +1112,7 @@ class Spectrum(PyoObject):
         the server GUI before showing the controller window.
 
         """
+        pyoArgsAssert(self, "SB", title, wxnoserver)
         createSpectrumWindow(self, title, wxnoserver)
 
     def _setViewFrame(self, frame):
@@ -1196,6 +1236,7 @@ class Scope(PyoObject):
 
     """
     def __init__(self, input, length=0.05, gain=0.67):
+        pyoArgsAssert(self, "oNN", input, length, gain)
         PyoObject.__init__(self)
         self.points = None
         self.viewFrame = None
@@ -1222,6 +1263,7 @@ class Scope(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -1235,6 +1277,7 @@ class Scope(PyoObject):
                 new `length` attribute.
 
         """
+        pyoArgsAssert(self, "N", x)
         self._length = x
         self._timer.time = x
         [obj.setLength(x) for obj in self._base_objs]
@@ -1249,6 +1292,7 @@ class Scope(PyoObject):
                 new `gain` attribute, as linear values.
 
         """
+        pyoArgsAssert(self, "n", x)
         self._gain = x
         x, lmax = convertArgsToLists(x)
         [obj.setGain(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
@@ -1264,6 +1308,7 @@ class Scope(PyoObject):
                 defaults to True.
 
         """
+        pyoArgsAssert(self, "B", active)
         if active:
             self._timer.play()
         else:
@@ -1283,6 +1328,7 @@ class Scope(PyoObject):
                 width is 500.
 
         """
+        pyoArgsAssert(self, "I", x)
         self._width = x
         [obj.setWidth(x) for obj in self._base_objs]
 
@@ -1300,6 +1346,7 @@ class Scope(PyoObject):
                 height is 400.
 
         """
+        pyoArgsAssert(self, "I", x)
         self._height = x
         [obj.setHeight(x) for obj in self._base_objs]
 
@@ -1319,6 +1366,7 @@ class Scope(PyoObject):
         the server GUI before showing the controller window.
 
         """
+        pyoArgsAssert(self, "SB", title, wxnoserver)
         createScopeWindow(self, title, wxnoserver)
 
     def _setViewFrame(self, frame):
@@ -1393,6 +1441,7 @@ class PeakAmp(PyoObject):
 
     """
     def __init__(self, input, function=None, mul=1, add=0):
+        pyoArgsAssert(self, "oCOO", input, function, mul, add)
         PyoObject.__init__(self, mul, add)
         self._input = input
         if callable(function):
@@ -1404,7 +1453,7 @@ class PeakAmp(PyoObject):
         self._base_objs = [PeakAmp_base(wrap(in_fader,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
         sr = self.getSamplingRate()
         bs = self.getBufferSize()
-        self._timer = Pattern(self._buildList, bs/sr).play()
+        self._timer = Pattern(self._buildList, 0.06).play()
 
     def setInput(self, x, fadetime=0.05):
         """
@@ -1418,6 +1467,7 @@ class PeakAmp(PyoObject):
                 Crossfade time between old and new input. Default to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -1431,9 +1481,23 @@ class PeakAmp(PyoObject):
                 New function to call with amplitude values in arguments.
 
         """
+        pyoArgsAssert(self, "C", x)
         if callable(x):
             self._function = getWeakMethodRef(x)
 
+    def polltime(self, x):
+        """
+        Sets the delay, in seconds, between each call of the function.
+
+        :Args:
+
+            x : float
+                New polling time in seconds.
+
+        """
+        pyoArgsAssert(self, "N", x)
+        self._timer.time = x
+
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
