@@ -31,10 +31,9 @@ GNU Lesser General Public License for more details.
 You should have received a copy of the GNU Lesser General Public
 License along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
-import sys
 from _core import *
 from _maps import *
-from types import IntType, ListType
+from types import ListType
 
 ######################################################################
 ### Open Sound Control
@@ -77,6 +76,7 @@ class OscSend(PyoObject):
 
     """
     def __init__(self, input, port, address, host="127.0.0.1"):
+        pyoArgsAssert(self, "oiss", input, port, address, host)
         PyoObject.__init__(self)
         self._input = input
         self._in_fader = InputFader(input)
@@ -95,6 +95,7 @@ class OscSend(PyoObject):
                 Crossfade time between old and new input. Defaults to 0.05.
 
         """
+        pyoArgsAssert(self, "oN", x, fadetime)
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
@@ -118,6 +119,7 @@ class OscSend(PyoObject):
                 Should be greater or equal to 1.
 
         """
+        pyoArgsAssert(self, "I", x)
         [obj.setBufferRate(x) for obj in self._base_objs]
 
     @property
@@ -169,10 +171,8 @@ class OscReceive(PyoObject):
     """
 
     def __init__(self, port, address, mul=1, add=0):
+        pyoArgsAssert(self, "IsOO", port, address, mul, add)
         PyoObject.__init__(self, mul, add)
-        if type(port) != IntType:
-            print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
-            exit()
         address, mul, add, lmax = convertArgsToLists(address, mul, add)
         self._address = address
         self._mainReceiver = OscReceiver_base(port, address)
@@ -207,6 +207,7 @@ class OscReceive(PyoObject):
                 Addition factor. Defaults to 0.
 
         """
+        pyoArgsAssert(self, "sOO", path, mul, add)
         path, lmax = convertArgsToLists(path)
         mul, add, lmax2 = convertArgsToLists(mul, add)
         for i, p in enumerate(path):
@@ -225,6 +226,7 @@ class OscReceive(PyoObject):
                 Path(s) to remove.
 
         """
+        pyoArgsAssert(self, "s", path)
         path, lmax = convertArgsToLists(path)
         self._mainReceiver.delAddress(path)
         indexes = [self._address.index(p) for p in path]
@@ -242,6 +244,7 @@ class OscReceive(PyoObject):
                 True activates the interpolation, False deactivates it.
 
         """
+        pyoArgsAssert(self, "B", x)
         [obj.setInterpolation(x) for obj in self._base_objs]
 
     def setValue(self, path, value):
@@ -256,6 +259,7 @@ class OscReceive(PyoObject):
                 Value to attribute to the given address.
 
         """
+        pyoArgsAssert(self, "sn", path, value)
         path, value, lmax = convertArgsToLists(path, value)
         for i in range(lmax):
             p = wrap(path,i)
@@ -309,11 +313,17 @@ class OscDataSend(PyoObject):
         types : str
             String specifying the types sequence of the message to be sent.
             Possible values are:
-                - integer : "i"
-                - long integer : "h"
-                - float : "f"
-                - double : "d"
-                - string : "s"
+                - "i" : integer
+                - "h" : long integer
+                - "f" : float
+                - "d" : double
+                - "s" ; string
+                - "b" : blob (list of chars)
+                - "m" : MIDI packet (list of 4 bytes: [midi port, status, data1, data2])
+                - "c" : char
+                - "T" : True
+                - "F" : False
+                - "N" : None (nil)
 
             The string "ssfi" indicates that the value to send will be a list
             containing two strings followed by a float and an integer.
@@ -335,16 +345,26 @@ class OscDataSend(PyoObject):
 
     >>> s = Server().boot()
     >>> s.start()
-    >>> a = OscDataSend("fissif", 9900, "/data/test")
     >>> def pp(address, *args):
     ...     print address
     ...     print args
-    >>> b = OscDataReceive(9900, "/data/test", pp)
+    >>> r = OscDataReceive(9900, "/data/test", pp)
+    >>> # Send various types
+    >>> a = OscDataSend("fissif", 9900, "/data/test")
     >>> msg = [3.14159, 1, "Hello", "world!", 2, 6.18]
     >>> a.send(msg)
+    >>> # Send a blob
+    >>> b = OscDataSend("b", 9900, "/data/test")
+    >>> msg = [[chr(i) for i in range(10)]]
+    >>> b.send(msg)
+    >>> # Send a MIDI noteon on port 0
+    >>> c = OscDataSend("m", 9900, "/data/test")
+    >>> msg = [[0, 144, 60, 100]]
+    >>> c.send(msg)
 
     """
     def __init__(self, types, port, address, host="127.0.0.1"):
+        pyoArgsAssert(self, "siss", types, port, address, host)
         PyoObject.__init__(self)
         types, port, address, host, lmax = convertArgsToLists(types, port, address, host)
         self._base_objs = [OscDataSend_base(wrap(types,i), wrap(port,i), wrap(address,i), wrap(host,i)) for i in range(lmax)]
@@ -396,6 +416,7 @@ class OscDataSend(PyoObject):
                 is the localhost.
 
         """
+        pyoArgsAssert(self, "siss", types, port, address, host)
         types, port, address, host, lmax = convertArgsToLists(types, port, address, host)
         objs = [OscDataSend_base(wrap(types,i), wrap(port,i), wrap(address,i), wrap(host,i)) for i in range(lmax)]
         self._base_objs.extend(objs)
@@ -412,6 +433,7 @@ class OscDataSend(PyoObject):
                 Path(s) to remove.
 
         """
+        pyoArgsAssert(self, "s", path)
         path, lmax = convertArgsToLists(path)
         for p in path:
             self._base_objs.remove(self._addresses[p])
@@ -433,8 +455,10 @@ class OscDataSend(PyoObject):
 
         """
         if address == None:
+            pyoArgsAssert(self, "l", msg)
             [obj.send(msg) for obj in self._base_objs]
         else:
+            pyoArgsAssert(self, "lS", msg, address)
             self._addresses[address].send(msg)
 
 class OscDataReceive(PyoObject):
@@ -477,25 +501,29 @@ class OscDataReceive(PyoObject):
 
     >>> s = Server().boot()
     >>> s.start()
-    >>> a = OscDataSend("fissif", 9900, "/data/test")
     >>> def pp(address, *args):
     ...     print address
     ...     print args
-    >>> b = OscDataReceive(9900, "/data/test", pp)
+    >>> r = OscDataReceive(9900, "/data/test", pp)
+    >>> # Send various types
+    >>> a = OscDataSend("fissif", 9900, "/data/test")
     >>> msg = [3.14159, 1, "Hello", "world!", 2, 6.18]
     >>> a.send(msg)
+    >>> # Send a blob
+    >>> b = OscDataSend("b", 9900, "/data/test")
+    >>> msg = [[chr(i) for i in range(10)]]
+    >>> b.send(msg)
+    >>> # Send a MIDI noteon on port 0
+    >>> c = OscDataSend("m", 9900, "/data/test")
+    >>> msg = [[0, 144, 60, 100]]
+    >>> c.send(msg)
 
     """
 
     def __init__(self, port, address, function):
+        pyoArgsAssert(self, "IsC", port, address, function)
         PyoObject.__init__(self)
-        if type(port) != IntType:
-            print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
-            exit()
         self._port = port
-        if not callable(function):
-            print >> sys.stderr, 'TypeError: "function" argument of %s must be callable.\n' % self.__class__.__name__
-            exit()
         self._function = WeakMethod(function)
         self._address, lmax = convertArgsToLists(address)
         # self._address is linked with list at C level
@@ -527,6 +555,7 @@ class OscDataReceive(PyoObject):
                 New path(s) to receive from.
 
         """
+        pyoArgsAssert(self, "s", path)
         path, lmax = convertArgsToLists(path)
         for p in path:
             if p not in self._address:
@@ -542,6 +571,7 @@ class OscDataReceive(PyoObject):
                 Path(s) to remove.
 
         """
+        pyoArgsAssert(self, "s", path)
         path, lmax = convertArgsToLists(path)
         for p in path:
             index = self._address.index(p)
@@ -592,13 +622,8 @@ class OscListReceive(PyoObject):
     """
 
     def __init__(self, port, address, num=8, mul=1, add=0):
+        pyoArgsAssert(self, "IsIOO", port, address, num, mul, add)
         PyoObject.__init__(self, mul, add)
-        if type(port) != IntType:
-            print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
-            exit()
-        if type(num) != IntType:
-            print >> sys.stderr, 'TypeError: "num" argument of %s must be an integer.\n' % self.__class__.__name__
-            exit()
         self._num = num
         self._op_duplicate = self._num
         address, mul, add, lmax = convertArgsToLists(address, mul, add)
@@ -637,6 +662,7 @@ class OscListReceive(PyoObject):
                 Addition factor. Defaults to 0.
 
         """
+        pyoArgsAssert(self, "sOO", path, mul, add)
         path, lmax = convertArgsToLists(path)
         mul, add, lmax2 = convertArgsToLists(mul, add)
         for i, p in enumerate(path):
@@ -655,6 +681,7 @@ class OscListReceive(PyoObject):
                 Path(s) to remove.
 
         """
+        pyoArgsAssert(self, "s", path)
         path, lmax = convertArgsToLists(path)
         self._mainReceiver.delAddress(path)
         indexes = [self._address.index(p) for p in path]
@@ -674,6 +701,7 @@ class OscListReceive(PyoObject):
                 True activates the interpolation, False deactivates it.
 
         """
+        pyoArgsAssert(self, "B", x)
         [obj.setInterpolation(x) for obj in self._base_objs]
 
     def setValue(self, path, value):
@@ -688,6 +716,7 @@ class OscListReceive(PyoObject):
                 List of values to attribute to the given address.
 
         """
+        pyoArgsAssert(self, "sl", path, value)
         path, lmax = convertArgsToLists(path)
         for i in range(lmax):
             p = wrap(path,i)
